translate.storage.html.POHTMLParser

Package translate :: Package storage :: Module html :: Class POHTMLParser |
[hide private]
[frames] | no frames]

# Class POHTMLParser

source code

Nested Classes | [hide private]
Inherited from `htmlfile`: `UnitClass`

Instance Methods | [hide private]
Inherited from `htmlfile`: `__init__`, `addhtmlblock`, `buildtag`, `do_encoding`, `endblock`, `guess_encoding`, `handle_charref`, `handle_comment`, `handle_data`, `handle_endtag`, `handle_entityref`, `handle_pi`, `handle_startendtag`, `handle_starttag`, `has_translatable_content`, `parse`, `pi_escape`, `pi_unescape`, `startblock` Inherited from `htmlfile` (private): `_simple_callback` Inherited from `HTMLParser.HTMLParser`: `check_for_whole_start_tag`, `clear_cdata_mode`, `close`, `error`, `feed`, `get_starttag_text`, `goahead`, `handle_decl`, `parse_endtag`, `parse_pi`, `parse_starttag`, `reset`, `set_cdata_mode`, `unescape`, `unknown_decl` Inherited from `markupbase.ParserBase`: `getpos`, `parse_comment`, `parse_declaration`, `parse_marked_section`, `updatepos` Inherited from `markupbase.ParserBase` (private): `_parse_doctype_attlist`, `_parse_doctype_element`, `_parse_doctype_entity`, `_parse_doctype_notation`, `_parse_doctype_subset`, `_scan_name` Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `__str__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `detect_encoding`, `findid`, `findunit`, `findunits`, `getids`, `getprojectstyle`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setprojectstyle`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
Inherited from `htmlfile`: `ENCODING_RE`, `INCLUDEATTRS`, `MARKINGATTRS`, `MARKINGTAGS`, `SELF_CLOSING_TAGS` Inherited from `HTMLParser.HTMLParser`: `CDATA_CONTENT_ELEMENTS`, `entitydefs` Inherited from `markupbase.ParserBase` (private): `_decl_otherchars` Inherited from `base.TranslationStore`: `Extensions`, `Mimetypes`, `Name`, `sourcelanguage`, `suggestions_in_format`, `targetlanguage` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`